// MainFrm.cpp : implementation of the CMainFrame class
//
// This is a part of the Microsoft Foundation Classes C++ library.
// Copyright (C) 1992-1997 Microsoft Corporation
// All rights reserved.
//
// This source code is only intended as a supplement to the
// Microsoft Foundation Classes Reference and related
// electronic documentation provided with the library.
// See these sources for detailed information regarding the
// Microsoft Foundation Classes product.

#include "stdafx.h"
#include "Scribble.h"

#include "MainFrm.h"
#include <afxpriv.h>
#include "childfrm.h"


#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CMainFrame

IMPLEMENT_DYNAMIC(CMainFrame, CMDIFrameWnd)

BEGIN_MESSAGE_MAP(CMainFrame, CMDIFrameWnd)
	//{{AFX_MSG_MAP(CMainFrame)
	ON_WM_CREATE()
	ON_COMMAND(ID_ENGLISH, OnLanguage)
	ON_UPDATE_COMMAND_UI(ID_ENGLISH, OnUpdateLanguage)
	ON_COMMAND(ID_GERMAN, OnLanguage)
	ON_UPDATE_COMMAND_UI(ID_GERMAN, OnUpdateLanguage)
	//}}AFX_MSG_MAP
	ON_COMMAND(ID_HELP_FINDER, CMDIFrameWnd::OnHelpFinder)
	ON_COMMAND(ID_HELP, CMDIFrameWnd::OnHelp)
	ON_COMMAND(ID_CONTEXT_HELP, CMDIFrameWnd::OnContextHelp)
	ON_COMMAND(ID_DEFAULT_HELP, CMDIFrameWnd::OnHelpFinder)
END_MESSAGE_MAP()

static UINT indicators[] =
{
	ID_SEPARATOR,           // status line indicator
	ID_INDICATOR_CAPS,
	ID_INDICATOR_NUM,
	ID_INDICATOR_SCRL,
};

/////////////////////////////////////////////////////////////////////////////
// CMainFrame construction/destruction

CMainFrame::CMainFrame():m_hLanguageDLL(NULL)
{
	// TODO: add member initialization code here
	
}

CMainFrame::~CMainFrame()
{
    if (m_hLanguageDLL)
        FreeLibrary(m_hLanguageDLL); 	

}

int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
	if (CMDIFrameWnd::OnCreate(lpCreateStruct) == -1)
		return -1;
	
	if (!m_wndToolBar.Create(this) ||
		!m_wndToolBar.LoadToolBar(IDR_MAINFRAME))
	{
		TRACE0("Failed to create toolbar\n");
		return -1;      // fail to create
	}

	if (!m_wndStatusBar.Create(this) ||
		!m_wndStatusBar.SetIndicators(indicators,
		  sizeof(indicators)/sizeof(UINT)))
	{
		TRACE0("Failed to create status bar\n");
		return -1;      // fail to create
	}

	// TODO: Remove this if you don't want tool tips
	m_wndToolBar.SetBarStyle(m_wndToolBar.GetBarStyle() |
		CBRS_TOOLTIPS | CBRS_FLYBY | CBRS_SIZE_DYNAMIC);
	
	// TODO: Delete these three lines if you don't want the toolbar to
	//  be dockable
	m_wndToolBar.EnableDocking(CBRS_ALIGN_ANY);
	EnableDocking(CBRS_ALIGN_ANY);
	DockControlBar(&m_wndToolBar);


	return 0;
}

BOOL CMainFrame::PreCreateWindow(CREATESTRUCT& cs)
{
	// TODO: Modify the Window class or styles here by modifying
	//  the CREATESTRUCT cs

	return CMDIFrameWnd::PreCreateWindow(cs);
}

/////////////////////////////////////////////////////////////////////////////
// CMainFrame diagnostics

#ifdef _DEBUG
void CMainFrame::AssertValid() const
{
	CMDIFrameWnd::AssertValid();
}

void CMainFrame::Dump(CDumpContext& dc) const
{
	CMDIFrameWnd::Dump(dc);
}

#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CMainFrame message handlers

void CMainFrame::OnLanguage() 
{
    HMODULE hCurrentModule;
    
    if (m_hLanguageDLL)
    {
        FreeLibrary(m_hLanguageDLL); 	
        m_hLanguageDLL=NULL;
        hCurrentModule=GetModuleHandle(NULL);
	}
    else
        hCurrentModule=m_hLanguageDLL=LoadLibrary(_T("scribdeu"));

    ASSERT(hCurrentModule); //is the resource DLL existent?
    
    AfxSetResourceHandle(hCurrentModule);

    CDocTemplate* pTemplate;
    POSITION pos;


    //Determining Scribbles CMultiDocTemplate:
    //if we had an appliction with more than one template, we would have to make a loop over
    //CScribbleApp's CMultiDocTemplate like this:
    /*
#if _MFC_VER>=0x400
    pos = AfxGetApp()->GetFirstDocTemplatePosition();
    while (pos!=NULL && (pTemplate=AfxGetApp()->GetNextDocTemplate(pos))!=NULL)
        {
#else    
    for( pos = m_templateList.GetHeadPosition(); pos != NULL; )
        {             
        pTemplate=(CDocTemplate *)m_templateList.GetNext( pos );
#endif
        ASSERT(pTemplate);      
        ASSERT(pTemplate->IsKindOf(RUNTIME_CLASS(CMultiDocTemplate)));       
        //Now change all MDI children's shared menus....

        }
    */


#if _MFC_VER>=0x400
    pos = AfxGetApp()->GetFirstDocTemplatePosition();
    ASSERT(pos);
    pTemplate=AfxGetApp()->GetNextDocTemplate(pos);    
#else
    pos = m_templateList.GetHeadPosition(); 
    ASSERT(pos);
    pTemplate=(CDocTemplate *)m_templateList.GetNext( pos );
#endif
    ASSERT(pTemplate);
    ASSERT(pTemplate->IsKindOf(RUNTIME_CLASS(CMultiDocTemplate)));
    

    CMenu DefaultMenu,SharedMenu;
    DefaultMenu.LoadMenu(IDR_MAINFRAME);
    SharedMenu.LoadMenu(IDR_SCRIBBTYPE);

    CMenu *pMenu = GetMenu();
    ASSERT(pMenu );
    
    if (pMenu->m_hMenu==m_hMenuDefault)
        SetMenu(&DefaultMenu);
    else
        {
        SetMenu(&SharedMenu);
        ::SendMessage(m_hWndMDIClient, WM_MDISETMENU,NULL, (LPARAM)GetWindowMenuPopup(SharedMenu.m_hMenu));
            //this re-populates the Window-Menu
        }
    ::DestroyMenu(m_hMenuDefault);
    ASSERT(((CMultiDocTemplate *)pTemplate)->m_hMenuShared);
    ::DestroyMenu(((CMultiDocTemplate *)pTemplate)->m_hMenuShared);

    m_hMenuDefault=DefaultMenu.m_hMenu;
    ((CMultiDocTemplate *)pTemplate)->m_hMenuShared=SharedMenu.m_hMenu;        


    POSITION docpos=pTemplate->GetFirstDocPosition( );
    CDocument *pDocument=NULL;
    while (docpos)
    {
        pDocument=pTemplate->GetNextDoc(docpos);
        ASSERT(pDocument);
        POSITION viewpos = pDocument->GetFirstViewPosition();
        CWnd *pParent;
        while (viewpos != NULL)
        {
            CView* pView = pDocument->GetNextView(viewpos);
            if (pView && NULL!=(pParent=pView->GetParentFrame()) && pParent->IsKindOf(RUNTIME_CLASS(CChildFrame)))
                ((CChildFrame *)pParent)->SharedMenu()=SharedMenu.m_hMenu;                    
                
        }   
    }

    m_wndStatusBar.SetIndicators(indicators,sizeof(indicators)/sizeof(UINT));
        //Update the other panes of status bar		
    SendMessage(WM_SETMESSAGESTRING, (WPARAM)AFX_IDS_IDLEMESSAGE);
    m_wndStatusBar.UpdateWindow();//Update 1st pane of status bar


    DefaultMenu.Detach();
    SharedMenu.Detach();
}

void CMainFrame::OnUpdateLanguage(CCmdUI* pCmdUI) 
{
    BOOL bVal=(pCmdUI->m_nID==ID_GERMAN && !m_hLanguageDLL || pCmdUI->m_nID==ID_ENGLISH &&	m_hLanguageDLL);
    pCmdUI->Enable(bVal);
    pCmdUI->SetCheck(!bVal);
}
